Date: 01 4, 2002 11:59:49 AM

# pranchor

## Purpose

OBSOLETE. Print a web URL to fileName. Treat the range (number1, number2) as a URL.

## Syntax

pranchor(fileName, number1, number2)

fileName - type: str
number1 - type: int
number2 - type: int

## Returns

## Remarks

Use the global variable named Base to resolve and print complete relative URLs. (A prior pass must find the <base> HTML tag and set Base appropriately. NOT yet using the file's URL, so not handling cases where <base> itself is a relative URL.)

The output file (fileName) must be set up in advance using openfile, fileout or an output statement.

## Example

## See Also

openfile, fileout, POST Actions